(hamming-distance s1 s2)Number of positions at which corresponding symbols are different
Number of positions at which corresponding symbols are different
(levenshtein-distance s1 s2)Minimum edit (replace/insert/delete) distance
The grid (of edit distances) is aligned as s2 on the top and s1 on the left
Minimum edit (replace/insert/delete) distance The grid (of edit distances) is aligned as s2 on the top and s1 on the left
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |